@@ -35,26 +35,48 @@ class BSM2OLEM(BSM2Base):
 
     Parameters
     ----------
-    data_in : np.ndarray (optional)
+    data_in : np.ndarray(n, 22) | str (optional)
         Influent data. Has to be a 2D array. <br>
-        First column is time in days, the rest are 21 components
-        (13 ASM1 components, TSS, Q, T and 5 dummy states). <br>
-        If not provided, the influent data from BSM2 is used.
+        First column is time [d], the rest are 21 components
+        (13 ASM1 components, TSS, Q, T and 5 dummy states).
+        If a string is provided, it is interpreted as a file name.
+        If not provided, the influent data from BSM2 is used. \n
+        [SI, SS, XI, XS, XBH, XBA, XP, SO, SNO, SNH, SND, XND, SALK, TSS, Q, TEMP, SD1, SD2, SD3, XD4, XD5]
     timestep : float (optional)
-        Timestep for the simulation [days]. <br>
-        If not provided, the timestep is calculated from the influent data.
+        Timestep for the simulation [d]. <br>
+        If not provided, the timestep is set to 1 minute. <br>
+        Please note: Due to sensor sensitivity, the timestep should not be larger than 1 minute.
     endtime : float (optional)
-        Endtime for the simulation [days]. <br>
+        Endtime for the simulation [d]. <br>
         If not provided, the endtime is the last time step in the influent data.
+    evaltime : int | np.ndarray(2) (optional)
+        Evaluation time for the simulation [d]. <br>
+        When passed as an int, it defines the number of last days of the simulation to be evaluated.
+        When passed as a 1D np.ndarray with two values, it defines the start and end time of the evaluation period.
+        If not provided, the last 5 days of the simulation will be assessed. \n
+        [starttime, self.simtime[-1]]
+    data_out : str (optional)
+        Path to the output data file. <br>
+        If not provided, no output data is saved.
     tempmodel : bool (optional)
-        If True, the temperature model dependencies are activated. <br>
-        Default is False.
+        If `True`, the temperature model dependencies are activated.
+        Default is `False`.
     activate : bool (optional)
-        If True, the dummy states are activated. <br>
-        Default is False.
+        If `True`, the dummy states are activated.
+        Default is `False`.
     """
 
-    def __init__(self, data_in=None, timestep=None, endtime=None, evaltime=None, *, tempmodel=False, activate=False):
+    def __init__(
+        self,
+        data_in: np.ndarray | str | None = None,
+        timestep: float | None = None,
+        endtime: float | None = None,
+        evaltime: int | np.ndarray | None = None,
+        data_out: str | None = None,
+        *,
+        tempmodel: bool = False,
+        activate: bool = False,
+    ):
         super().__init__(
             data_in=data_in,
             timestep=timestep,
@@ -62,10 +84,11 @@ class BSM2OLEM(BSM2Base):
             evaltime=evaltime,
             tempmodel=tempmodel,
             activate=activate,
+            data_out=data_out,
         )
         self.perf_factors_all = np.zeros((len(self.simtime), 14))
 
-        self.timestep_hour = np.dot(self.timestep, 24)
+        self.timestep_hour = np.dot(self.timesteps, 24)
 
         # scenario 5, 75th percentile, 50% reduction when S_NH below 4g/m3
         self.controller = ControllerEM(0.75, self.klas, 0.5, 4, BIOGAS, O2, CH4)
@@ -164,6 +187,16 @@ class BSM2OLEM(BSM2Base):
         self.heat_net_temp_all = np.zeros((len(self.simtime), 1))
 
     def step(self, i: int, *, stabilized: bool = False):
+        """Simulates the one time step of the BSM2 model.
+
+        Parameters
+        ----------
+        i : int
+            Index of the current time step [-].
+        stabilized : bool
+            If `True`, plant is stabilized after iterations.
+        """
+
         self.klas = self.controller.get_klas(self.simtime[i], self.y_eff[SNH])
 
         super().step(i)
@@ -333,15 +366,15 @@ class BSM2OLEM(BSM2Base):
         Returns
         -------
         gas_production : float
-            Gas production of the plant [Nm³/h].
-        gas_parameters : np.ndarray
+            Gas production of the plant [Nm³ ⋅ h⁻¹].
+        gas_parameters : np.ndarray(5)
             Array that contains five gas parameters of the produced gas. <br>
             [p_H2, p_CH4, p_CO2, P_gas, q_gas] \n
             - p_H2: Pressure fracture of hydrogen [bar].
             - p_CH4: Pressure fracture of methane [bar].
             - p_CO2: Pressure fracture of carbon dioxide [bar].
             - P_gas: Total pressure of the gas mixture [bar].
-            - q_gas: Gas production of the plant [Nm³/d].
+            - q_gas: Gas production of the plant [Nm³ ⋅ d⁻¹].
         """
 
         gas_production = self.yd_out[-1] / 24  # Nm3/d -> Nm3/h
@@ -356,26 +389,26 @@ class BSM2OLEM(BSM2Base):
         Parameters
         ----------
         pe : float
-            The pumping energy of the plant [kWh/d].
+            Pumping energy of the plant [kWh ⋅ d⁻¹].
         ae : float
-            The aeration energy of the plant [kWh/d].
+            Aeration energy of the plant [kWh ⋅ d⁻¹].
         me : float
-            The mixing energy of the plant [kWh/d].
+            Mixing energy of the plant [kWh ⋅ d⁻¹].
         eg : float
-            The electricity generation of the plant [kWh/d].
+            Electricity generation of the plant [kWh ⋅ d⁻¹].
         tss : float
-            The total suspended solids production of the plant [kg/d].
+            Total suspended solids production of the plant [kg ⋅ d⁻¹].
         cm : float
-            The added carbon mass of the plant [kg/d].
+            Added carbon mass of the plant [kg ⋅ d⁻¹].
         hd : float
-            The heating demand of the sludge [kWh/d].
+            Heating demand of the sludge [kWh ⋅ d⁻¹].
         hp : float
-            The heat production of the plant [kWh/d].
+            Heat production of the plant [kWh ⋅ d⁻¹].
 
         Returns
         -------
-        float
-            The operational cost index of the plant.
+        oci : float
+            Operational cost index of the plant [-].
         """
 
         tss_cost = 3 * tss
@@ -394,30 +427,30 @@ class BSM2OLEM(BSM2Base):
         Parameters
         ----------
         pe : float
-            The pumping energy of the plant [kWh/d].
+            Pumping energy of the plant [kWh ⋅ d⁻¹].
         ae : float
-            The aeration energy of the plant [kWh/d].
+            Aeration energy of the plant [kWh ⋅ d⁻¹].
         me : float
-            The mixing energy of the plant [kWh/d].
+            Mixing energy of the plant [kWh ⋅ d⁻¹].
         eg : float
-            The electricity generation of the plant [kWh/d].
+            Electricity generation of the plant [kWh ⋅ d⁻¹].
         tss : float
-            The total suspended solids production of the plant [kg/d].
+            Total suspended solids production of the plant [kg ⋅ d⁻¹].
         cm : float
-            The added carbon mass of the plant [kg/d].
+            Added carbon mass of the plant [kg ⋅ d⁻¹].
         hd : float
-            The heating demand of the sludge [kWh/d].
+            Heating demand of the sludge [kWh ⋅ d⁻¹].
         hp : float
-            The heat production of the plant [kWh/d].
+            Heat production of the plant [kWh ⋅ d⁻¹].
         simtime : float or none
             The current time step [d]. <br>
-            Only needed if dyn is True. <br>
+            Only needed if dyn is True.
             Defaults to None.
 
         Returns
         -------
-        float
-            The operational cost index of the plant.
+        oci_dyn : float
+            Operational cost index of the plant, while considering the dynamic electricity prices [-].
         """
 
         tss_cost = 3 * tss
@@ -446,33 +479,33 @@ class BSM2OLEM(BSM2Base):
         Returns
         -------
         iqi_eval : float
-            The final iqi value [kg/d].
+            Final iqi value [kg ⋅ d⁻¹].
         eqi_eval : float
-            The final eqi value [kg/d].
+            Final eqi value [kg ⋅ d⁻¹].
         tot_sludge_prod : float
-            The total sludge production [kg/d].
+            Total sludge production [kg ⋅ d⁻¹].
         tot_tss_mass : float
-            The total tss mass [kg/d].
+            Total tss mass [kg ⋅ d⁻¹].
         carb_mass : float
-            The carbon mass [kg_COD/d].
+            Carbon mass [kg(COD) ⋅ d⁻¹].
         ch4_prod : float
-            The methane production [kg_CH4/d].
+            Methane production [kg(CH4) ⋅ d⁻¹].
         h2_prod : float
-            The hydrogen production [kg_H2/d].
+            Hydrogen production [kg(H2) ⋅ d⁻¹].
         co2_prod : float
-            The carbon dioxide production [kg_CO2/d].
+            Carbon dioxide production [kg(CO2) ⋅ d⁻¹].
         q_gas : float
-            The total gas production [m³/d].
+            Total gas production [m³ ⋅ d⁻¹].
         heat_demand : float
-            The heat demand [kWh/d].
+            Heat demand [kWh ⋅ d⁻¹].
         mixingenergy : float
-            The mixing energy [kWh/d].
+            Mixing energy [kWh ⋅ d⁻¹].
         pumpingenergy : float
-            The pumping energy [kWh/d].
+            Pumping energy [kWh ⋅ d⁻¹].
         aerationenergy : float
-            The aeration energy [kWh/d].
+            Aeration energy [kWh ⋅ d⁻¹].
         oci_eval : float
-            The final oci value.
+            Final oci value [-].
         """
 
         # calculate the final performance values
